@@ -1,6 +1,6 @@
 package Bio::Palantir::Parser;
 # ABSTRACT: front-end class for Bio::Palantir::Parser module, wich handles the parsing of biosynML.xml and regions.js antiSMASH reports
-$Bio::Palantir::Parser::VERSION = '0.200150';
+$Bio::Palantir::Parser::VERSION = '0.200290';
 use Moose;
 use namespace::autoclean;
 
@@ -34,7 +34,7 @@ has 'root' => (
 has 'module_delineation' => (
     is      => 'ro',
     isa     => 'Str',
-    default => 'selection',
+    default => 'substrate-selection',
 );
 
 ## no critic (ProhibitUnusedPrivateSubroutines)
@@ -390,7 +390,7 @@ Bio::Palantir::Parser - front-end class for Bio::Palantir::Parser module, wich h
 
 =head1 VERSION
 
-version 0.200150
+version 0.200290
 
 =head1 SYNOPSIS
 
